@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: 2022 UChicago Argonne, LLC
+# SPDX-FileCopyrightText: 2022-2023 UChicago Argonne, LLC
 # SPDX-License-Identifier: MIT
 
 from collections.abc import Sequence
@@ -23,10 +23,12 @@ class Database(Sequence):
 
     Attributes
     ----------
-    path
-        Base path for the database directory
     default_path
         Path used by default when creating instances if no path is specified
+    job_id
+        Integer ID assigned to new results
+    path
+        Base path for the database directory
     results
         List of simulation results in database
 
@@ -70,6 +72,14 @@ class Database(Sequence):
             except Exception:
                 warn(f"Could not read results from {dir}")
 
+        # Determine unique job ID based on what has already been used
+        used_job_ids = set()
+        for result in self:
+            job_id = getattr(result, 'job_id', None)
+            if job_id is not None:
+                used_job_ids.add(job_id)
+        self.job_id = max(used_job_ids, default=-1) + 1
+
         # Add instance to class-wide dictionary
         Database._instances[path.resolve()] = self
 
